.\$Id: caldate.man,v 1.4 2013/09/13 23:36:28 doug Exp $ 
.\ man page for caldate
.TH CALDATE 1 "13 September 2013" BDSN
.SH NAME
caldate
.SH SYNOPSIS
.B caldate
[\ \fB\-f\ \fI output_format\fR]
[\ \fB\-D\ j\ |\ m\ |\ IC\ |\ IO\fR ]
[\ \fIdate\fR\ ]
[\ \fIdate_modifiers ...\fR\ ]
.br
.B caldate
[\ \fB\-f\ \fI output_format\fR]
\fB\-i | -d date_time_1 date_time_2\fR
.br
.B caldate
\fB\-s date_time_1 date_time_2\fR
.br
.B caldate
[\ \fB\-h\fR\ ]

.SH DESCRIPTION
The program
.B caldate
performs arithmetic operations on date and time strings, and prints the
final date and time string in a user-specified format.  It can be used to
simply convert a date and time from one format to another format, or can be
used to add and subtract various units of time from the initial date and
time.  It may also be used to compute the time difference between 2 dates.

You may add or subtract time from the initial date in units of fractional
seconds, seconds, minutes, hours, days, months, and years.  Multiple
operations can be specified, and will be performed in the order in which
they are given.

The output format can be specified to control which fields are output, the
order of the fields, and may include delimiting characters and strings.
.SH OPTIONS
.TP
\fB\-f \fIoutput_format\fR
.br
specifies the format of the output string in a format similar to that used
by the
.B date(1) 
command.
The format for the output is similar to that of
the first argument to
.BR printf (3V).
All output fields are of fixed size (zero padded
if necessary).
Each field descriptor is preceded by
.B %
and will be replaced in the output by
its corresponding value.
A single
.B %
is encoded by
.BR %% .
All other
characters are copied to the output without change.
The string is always terminated with a new-line character.
.sp
Field Descriptors:
.RS
.PD 0
.TP 5
.B  Y
all 4 digits digits of year \- 0000 to 9999
.TP 5
.B  y
last  digits of year \- 00 to 99
.TP 5
.B  m
month of year \- 01 to 12
.TP 5
.B  d
day of month \- 01 to 31
.TP 5
.B  j
day of year \- 001 to 366
.TP 5
.B  H
hour \- 00 to 23
.TP 5
.B  M
minute \- 00 to 59
.TP 5
.B  S
second \- 00 to 60 (including leapseconds)
.TP 5
.B F
fractional portion of second \- 0000 to 9999
.TP 5
.B U
microseconds \- 000000 to 999999
.TP 5
.B n
nominal epoch seconds (trucated to 1 second precision)
.TP 5
.B N
nominal epoch seconds (microsecond precision)
.TP 5
.B t
true epoch seconds (truncated to 1 second precision)
.TP 5
.B T
true epoch seconds (microsecond precision)
.br
.PD
.RE
.sp
.RS
The default output format %Y.%j,%F:%M:%S.%F is used if no format is specified.
.RE
.TP
.B \-D j | m | IC | IO
specifies that the default output format should be one of the following
format for the date and time:
.nf 
	j = year.doy,HH:MM:SS (day-of-year, aka julian format)
	m = year/mm/dd,HH:MM:SS (month format)
	IC = year-mm-ddThh:mm:ss (ISO 8601 Calendar format)
	IO = year-doyThh:mm:ss (ISO 8601 Oridinal format)
.fiThe default is day-of-year format.
The \fB-f\fR option overrides this option.
.TP
.B \-h
print out a simple help message with syntax and explaination of the options.
.TP
\fIdate\fR
specifies the initial date.  The date may be in one of the following strings:
.nf
	l, local, c, current    - local time
	u, utc, g, gmt          - utc time
or it may be a user-specified date one of the following formats:
.nf
	yyyy/mm/dd/hh:mm:ss.ffff
	yyyy/mm/dd.hh:mm:ss.ffff
	yyyy/mm/dd,hh:mm:ss.ffff
	yyyy.doy.hh:mm:ss.ffff
	yyyy.doy,hh:mm:ss.ffff
	yyyy,doy,hh:mm:ss.ffff
	yyyy-mm-ddThh:mm:ss.ffffff
	yyyy-doyThh:mm:ss.ffffff
	nominal_epoch_timeN
	true_epoch_timeT
.fi
where the first set of format specify the year, month, day, and time, and the
second set of  formats specify year, day-of-year, and time.  All trailing components
of the time are optional, and if not specified, are assumed to be 0.
The time may also be specified in nominal_epoch or true_epoch time,
where nominal_epoch_time is the nominal number of seconds from
1970/01/01,00:00:00 and is terminated with the character 'N',
and true_epoch_time is the true number of seconds (including leap seconds) from 
1970/01/01,00:00:00 and is terminated with the character 'T'.
.br

.TP
\fIdate_modifiers\fR 
are optional strings that specify the computation that should be performed
on the date.  The operations will be performed in the order in which they
are specified.  Each modifier consists of a sign, and integer value, and a unit
specification, which is identical to the unit specification for the output format.
The unit specifiers are:
.nf
	y   - year
	m   - month
	d   - day
	H   - hour
	M   - minute
	S   - second
	F   - fractional second (4 digits)
	U   - microseconds (6 digits)
.fi
Note that each modified MUST begin with either a "+" or a "-".
.TP
\fB\-i | \-d | \-s \fIdate_time_1 date_time_2\fR
.br
computes the absolute value of the time interval (|t1-t2|), the time
difference (t1-t2), or the time difference in seconds (t1-t2) between the
two specified date_times, and outputs the result in the specified format.
If the time difference in seconds is requested, the user-specifed format is
ignored, and the output will be in the format "%S.%F".
.SH EXAMPLES
1.  Output the current local date and time.
.br
	caldate local

2.  Output the UTC date and time in day-of-year format.
.br
	caldate -f %Y.%d,%H:%M:%S utc

3.  Add 1 hour and then subtract 5 minutes to the current time, and output
in the default format. 
.br
	caldate l +1H -5m

4.  Add 1 day to the utc time and output only the date.
.br	
	caldate -f %Y.%j utc +1d

5.  Add 1 month to the current date.
.br
	caldate -f %Y/%m/%d,%H:%M:%S local +1m

.SH NOTES
For the purpose of performing computations on the date and time, the date
and time are represented by fields for the year, day_of_year, hour, minute,
second, and fractional second.  For each specified computation, the
specified value is added or subtracted from the specified field, and then
renormalized to a valid date and time.  Only when a computation involves
months is the internal format of year, month, and day used, and it is
immediately converted back to year, day_of_year after the computation has
been performed.  Therefore, the computation:
.br
	caldate -f %Y/%m/%d 2000/05/01 +12m
.br
will return the date 2001/05/01, but the computation
.br
	caldate -f %Y/%m/%d 2000/05/01 +1y
.br
will return the date 2001/05/02.

Leapseconds are also accounted for when calculating times, and the following
illustrates how leapsecond calculations are performed as well as the
importance of the order of the computation.  The computation:
.br
	caldate 1992/06/30 +1d -1S
.br
will result in 1992/06/30/23:59:60.0000 but the computation:
.br
	caldate 1992/06/30 -1S +1d
.br
will result in 1992/06/30,23:59:59.0000, 
since the day 1993/06/30 has a leap second in it.
.SH BUGS
Computations involving years are problematic, since a user may mean:
add one year to this year,day-of-year_day, or add 1 year to this year,month,day.
If a leap year is involved, they may return different dates.
.SH AUTHOR
Doug Neuhauser, doug@seismo.berkeley.edu.

